#!/usr/bin/env python3
"""
LucidX - AI-Powered Image Synthesis Engine
Author: Alex a.k.a. VritraSec
GitHub: https://github.com/VritraSecz/LucidX
"""

__version__ = "1.0.4"
__author__ = "Alex Butler [Vritra Security Organization]"
__email__ = "None"
__description__ = "AI-powered image synthesis engine using Stability AI API"

from .main import main

__all__ = ['main']
