#!/usr/bin/env python3
# Author: Alex a.k.a. VritraSec
# Project: LucidX — AI-Powered Image Synth Engine
# GitHub: https://github.com/VritraSecz

from colorama import Fore, Style, init

CYAN = Fore.CYAN + Style.BRIGHT
RED = Fore.LIGHTRED_EX
VALUE = "\033[38;2;255;189;89m"
QUOTE_BLUE = "\033[38;2;123;167;245m"
MODE = "\033[38;2;147;220;255m"
GREEN = "\x1b[38;2;102;255;102m"
WHITE = "\033[97m"
GRAY = "\033[90m"
RESET = "\033[0m"
